==> poresim-0.1.0.tar.gz: poresim-0.1.0/README.md <==
[![PyPI Version](https://img.shields.io/badge/PyPI-0.1.0-orange)](https://pypi.org/project/PoreSim/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/Ajax23/PoreSim/blob/master/LICENSE)
[![DOI](https://zenodo.org/badge/343372462.svg)](https://zenodo.org/badge/latestdoi/343372462)
[![Build Status](https://travis-ci.com/Ajax23/PoreSim.svg?branch=master)](https://travis-ci.com/Ajax23/PoreSim)
[![codecov](https://codecov.io/gh/Ajax23/PoreSim/branch/master/graph/badge.svg)](https://codecov.io/gh/Ajax23/PoreSim)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/Ajax23/PoreSim.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Ajax23/PoreSim/context:python)

## Documentation

Online documentation is available at [ajax23.github.io/PoreSim](http://ajax23.github.io/PoreSim).

The docs include an example for creating [simulation boxes](http://ajax23.github.io/PoreSim/simulation.html), and an [API reference](http://ajax23.github.io/PoreSim/api.html).


## Dependencies

PoreSim supports Python 3.5+.

Installation requires [pyyaml](https://pypi.org/project/PyYAML/) and [porems](https://pypi.org/project/porems/).


## Installation

You may instead want to use the development version from GitHub:

    pip install git+https://github.com/ajax23/PoreSim.git#egg=poresim

    pip install git+https://github.com/ajax23/PoreSim.git@develop#egg=poresim

Or download the repository and install in the top directory via:

    pip install .


## Testing

To test PoreSim, run the test in the test directory.


## Development

PoreSim development takes place on Github: [www.github.com/Ajax23/PoreSim](https://github.com/Ajax23/PoreSim)

Please submit any reproducible bugs you encounter to the [issue tracker](https://github.com/Ajax23/PoreSim/issues).


## How to Cite PoreSim

When citing PoreSim please use the current **Zenodo DOI** corresponding to the used PoreSim version. (Current DOI is listed in the badges.)

==> poresim-0.1.1.tar.gz: poresim-0.1.1/README.md <==
# PoreSim: Pore System Simulation Generator

[![PyPI Version](https://img.shields.io/badge/PyPI-0.1.1-orange)](https://pypi.org/project/PoreSim/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/Ajax23/PoreSim/blob/master/LICENSE)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5993763.svg)](https://doi.org/10.5281/zenodo.5993763)
[![Build Status](https://github.com/Ajax23/PoreSim/actions/workflows/workflow.yml/badge.svg)](https://github.com/Ajax23/PoreSim/actions/workflows/workflow.yml)
[![codecov](https://codecov.io/gh/Ajax23/PoreSim/branch/master/graph/badge.svg)](https://codecov.io/gh/Ajax23/PoreSim)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/Ajax23/PoreSim.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Ajax23/PoreSim/context:python)

## Documentation

Online documentation is available at [ajax23.github.io/PoreSim](http://ajax23.github.io/PoreSim).

The docs include an example for creating [simulation boxes](http://ajax23.github.io/PoreSim/simulation.html), and an [API reference](http://ajax23.github.io/PoreSim/api.html).


## Dependencies

PoreSim supports Python 3.5+.

Installation requires [pyyaml](https://pypi.org/project/PyYAML/).


## Installation

You may instead want to use the development version from GitHub:

    pip install git+https://github.com/ajax23/PoreSim.git#egg=poresim

    pip install git+https://github.com/ajax23/PoreSim.git@develop#egg=poresim

Or download the repository and install in the top directory via:

    pip install .


## Testing

To test PoreSim, run the test in the test directory.


## Development

PoreSim development takes place on Github: [www.github.com/Ajax23/PoreSim](https://github.com/Ajax23/PoreSim)

Please submit any reproducible bugs you encounter to the [issue tracker](https://github.com/Ajax23/PoreSim/issues).


## How to Cite PoreSim

When citing PoreSim please use the current **Zenodo DOI** corresponding to the used PoreSim version. (Current DOI is listed in the badges.)
